@@ -7,16 +7,26 @@
 #' \item{PM}{Partitioning matrix}
 #' \item{tab}{tabulation of the clustering}
 #' \item{Loss}{Loss function value of the solution}
-
-#' @export
 #'
 #' @examples
-#' data('ExampleData', package = 'CICA')
-#' output <- CICA(DataList = ExampleData, nStarts = 3, nComp = 5, nClus = 3, verbose = FALSE)
-#' summary(output)
+#' \dontrun{
+#' CICA_data <- Sim_CICA(Nr = 15, Q = 5, R = 4, voxels = 100, timepoints = 10,
+#' E = 0.4, overlap = .25, externalscore = TRUE)
+#'
+#' multiple_output = CICA(DataList = CICA_data$X, nComp = 2:6, nClus = 1:5,
+#' userGrid = NULL, RanStarts = 30, RatStarts = NULL, pseudo = c(0.1, 0.2),
+#' pseudoFac = 2, userDef = NULL, scalevalue = 1000, center = TRUE,
+#' maxiter = 100, verbose = TRUE, ctol = .000001)
+#'
+#' summary(multiple_output$Q_5_R_4)
+#' }
+#'
+#'
+#' @export
+#'
+#'
 summary.CICA <- function(object, ...){
 
-  names(object$P) <- 1:length(object$P)
 
   cat('Partitioning matrix P: \n' )
   PB <- matrix(0, nrow = length(object$P), ncol = length(unique(object$P)))
@@ -24,7 +34,7 @@ summary.CICA <- function(object, ...){
     PB[i, object$P[i]] <- 1
   }
   colnames(PB) <- paste('Cluster',sort(unique(object$P)))
-
+  rownames(PB) <- names(object$P)
   cat('\n')
   print(PB)
 
@@ -40,10 +50,10 @@ summary.CICA <- function(object, ...){
 
   cat('Loss function value of optimal solution is: ', object$Loss,'\n')
 
-  out <- list()
-  out$PM <- PB
-  out$tab <- tab
-  out$loss <- object$Loss
-
-  return(out)
+  # out <- list()
+  # out$PM <- PB
+  # out$tab <- tab
+  # out$loss <- object$Loss
+  #
+  # return(out)
 }
